@@ -2,4 +2,4 @@ package T3;
 use Object::Simple;
 sub x : Attr { default => sub{[1]} }
 
-Object::Simple->end;
+Object::Simple->build_class;
